<?php

namespace Chemical\Supplier\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Chemical\Supplier\Interfaces\SupplierRepositoryInterface;

class SupplierPublicController extends BaseController
{
    // use SupplierWorkflow;

    /**
     * Constructor.
     *
     * @param type \Chemical\Supplier\Interfaces\SupplierRepositoryInterface $supplier
     *
     * @return type
     */
    public function __construct(SupplierRepositoryInterface $supplier)
    {
        $this->repository = $supplier;
        parent::__construct();
    }

    /**
     * Show supplier's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $suppliers = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('$supplier::supplier.names'))
            ->view('supplier::supplier.index')
            ->data(compact('suppliers'))
            ->output();
    }


    /**
     * Show supplier.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $supplier = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($$supplier->name . trans('supplier::supplier.name'))
            ->view('supplier::supplier.show')
            ->data(compact('supplier'))
            ->output();
    }

}
